@@ -15,19 +15,21 @@ Software by: MVTec Software GmbH, www.mvtec.com
 # Make everything from operator_set visible when importing halcon.
 from .operator_set import *
 
-from .hobject import HObject
+from .ffi import HError, HOperatorError, HTupleConversionError, HNull
+from .hdev_operator import HDevOperatorBase
 from .hhandle import HHandle
-from .ffi import HError, HOperatorError, HTupleConversionError
-from .interop import HInteropError
+from .hobject import HObject
 from .hdevengine import (
-    HDevEngineError,
+    HDevEmptyVector,
     HDevEngine,
+    HDevEngineError,
     HDevProcedure,
     HDevProcedureCall,
     HDevProgram,
     HDevProgramCall,
+    HDevVectorConversionError,
 )
-
+from .interop import HInteropError
 
 # Import all interop to facilitate ha.* style namespace resolution,
 # in an ergonomic, consistent and readable way.
